@@ -9,12 +9,16 @@
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
+ *
+ * @(#) dirent2.h 1.3 94/12/17 16:26:16
  */
 
 #ifndef _DIRENT
 #define _DIRENT
 
-#include "tcl.h"
+#ifndef _TCL
+#include <tcl.h>
+#endif
 
 /*
  * Dirent structure, which holds information about a single
@@ -48,8 +52,8 @@ typedef struct _dirdesc {
  * Procedures defined for reading directories:
  */
 
-extern void		closedir (DIR *dirp);
-extern DIR *		opendir (char *name);
-extern struct dirent *	readdir (DIR *dirp);
+extern void		closedir _ANSI_ARGS_((DIR *dirp));
+extern DIR *		opendir _ANSI_ARGS_((char *name));
+extern struct dirent *	readdir _ANSI_ARGS_((DIR *dirp));
 
 #endif /* _DIRENT */
