@@ -11,6 +11,8 @@
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  */
 
+static char sccsid[] = "@(#) fixstrtod.c 1.4 95/07/27 12:59:26";
+
 #include <stdio.h>
 
 #undef strtod
@@ -20,12 +22,12 @@
  * somes systems (e.g. SunOS 4.1.4) stdlib.h doesn't declare strtod.
  */
 
-extern double strtod(char *, char **);
+extern double strtod();
 
 double
-fixstrtod(
-    char *string,
-    char **endPtr)
+fixstrtod(string, endPtr)
+    char *string;
+    char **endPtr;
 {
     double d;
     d = strtod(string, endPtr);
