@@ -1,6 +1,8 @@
 # parray:
 # Print the contents of a global array on stdout.
 #
+# @(#) parray.tcl 1.8 95/03/29 10:26:43
+#
 # Copyright (c) 1991-1993 The Regents of the University of California.
 # Copyright (c) 1994 Sun Microsystems, Inc.
 #
@@ -10,7 +12,7 @@
 
 proc parray {a {pattern *}} {
     upvar 1 $a array
-    if {![array exists array]} {
+    if ![array exists array] {
 	error "\"$a\" isn't an array"
     }
     set maxl 0
