@@ -14,7 +14,7 @@
  *
  */
 
-static char sccsid[] = "@(#) tclCkalloc.c 1.9 95/06/19 10:33:11";
+static char sccsid[] = "@(#) tclCkalloc.c 1.10 95/09/20 16:43:24";
 
 #include "tclInt.h"
 
@@ -393,7 +393,7 @@ Tcl_DbCkfree(ptr, file, line)
      * even though BODY_OFFSET is in words on these machines).
      */
 
-    struct mem_header *memp = (struct mem_header *) \
+    struct mem_header *memp = (struct mem_header *)
 	    (((unsigned long) ptr) - BODY_OFFSET);
 
     if (alloc_tracing)
@@ -459,7 +459,7 @@ Tcl_DbCkrealloc(ptr, size, file, line)
      * line.
      */
 
-    struct mem_header *memp = (struct mem_header *) \
+    struct mem_header *memp = (struct mem_header *)
 	    (((unsigned long) ptr) - BODY_OFFSET);
 
     copySize = size;
