@@ -14,7 +14,7 @@
  */
 
 #ifndef lint
-static char sccsid[] = "@(#) tclCmdMZ.c 1.57 95/04/30 14:35:17";
+static char sccsid[] = "@(#) tclCmdMZ.c 1.58 95/08/04 09:58:00";
 #endif
 
 #include "tclInt.h"
@@ -122,7 +122,7 @@ Tcl_RegexpCmd(dummy, interp, argc, argv)
 	pattern = Tcl_DStringValue(&patternDString);
 	for (p = pattern; *p != 0; p++) {
 	    if (isupper(UCHAR(*p))) {
-		*p = tolower(*p);
+		*p = tolower(UCHAR(*p));
 	    }
 	}
 	Tcl_DStringInit(&stringDString);
@@ -130,7 +130,7 @@ Tcl_RegexpCmd(dummy, interp, argc, argv)
 	string = Tcl_DStringValue(&stringDString);
 	for (p = string; *p != 0; p++) {
 	    if (isupper(UCHAR(*p))) {
-		*p = tolower(*p);
+		*p = tolower(UCHAR(*p));
 	    }
 	}
     } else {
@@ -270,7 +270,7 @@ Tcl_RegsubCmd(dummy, interp, argc, argv)
 	pattern = Tcl_DStringValue(&patternDString);
 	for (p = pattern; *p != 0; p++) {
 	    if (isupper(UCHAR(*p))) {
-		*p = tolower(*p);
+		*p = tolower(UCHAR(*p));
 	    }
 	}
 	Tcl_DStringInit(&stringDString);
@@ -278,7 +278,7 @@ Tcl_RegsubCmd(dummy, interp, argc, argv)
 	string = Tcl_DStringValue(&stringDString);
 	for (p = string; *p != 0; p++) {
 	    if (isupper(UCHAR(*p))) {
-		*p = tolower(*p);
+		*p = tolower(UCHAR(*p));
 	    }
 	}
     } else {
@@ -1134,7 +1134,7 @@ Tcl_StringCmd(dummy, interp, argc, argv)
 	Tcl_SetResult(interp, argv[2], TCL_VOLATILE);
 	for (p = interp->result; *p != 0; p++) {
 	    if (isupper(UCHAR(*p))) {
-		*p = tolower(*p);
+		*p = tolower(UCHAR(*p));
 	    }
 	}
 	return TCL_OK;
@@ -1150,7 +1150,7 @@ Tcl_StringCmd(dummy, interp, argc, argv)
 	Tcl_SetResult(interp, argv[2], TCL_VOLATILE);
 	for (p = interp->result; *p != 0; p++) {
 	    if (islower(UCHAR(*p))) {
-		*p = toupper(*p);
+		*p = toupper(UCHAR(*p));
 	    }
 	}
 	return TCL_OK;
