@@ -4,26 +4,12 @@
  *	Declarations of things used internally by the Tcl interpreter.
  *
  * Copyright (c) 1987-1993 The Regents of the University of California.
- * All rights reserved.
+ * Copyright (c) 1994-1995 Sun Microsystems, Inc.
  *
- * Permission is hereby granted, without written agreement and without
- * license or royalty fees, to use, copy, modify, and distribute this
- * software and its documentation for any purpose, provided that the
- * above copyright notice and the following two paragraphs appear in
- * all copies of this software.
- * 
- * IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE TO ANY PARTY FOR
- * DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT
- * OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF THE UNIVERSITY OF
- * CALIFORNIA HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * See the file "license.terms" for information on usage and redistribution
+ * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * THE UNIVERSITY OF CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES,
- * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS
- * ON AN "AS IS" BASIS, AND THE UNIVERSITY OF CALIFORNIA HAS NO OBLIGATION TO
- * PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
- *
- * $Header: /user6/ouster/tcl/RCS/tclInt.h,v 1.94 93/10/15 16:36:51 ouster Exp $ SPRITE (Berkeley)
+ * @(#) tclInt.h 1.106 95/08/25 15:44:50
  */
 
 #ifndef _TCLINT
@@ -356,7 +342,7 @@ typedef struct HistoryRev {
 				 * current history event. */
     int newSize;		/* Number of bytes in newBytes. */
     char *newBytes;		/* Replacement for the range given by
-				 * firstIndex and lastIndex. */
+				 * firstIndex and lastIndex (malloced). */
     struct HistoryRev *nextPtr;	/* Next in chain of revisions to apply, or
 				 * NULL for end of list. */
 } HistoryRev;
@@ -419,15 +405,21 @@ typedef struct MathFunc {
 
 /*
  *----------------------------------------------------------------
- * This structure defines an interpreter, which is a collection of
- * commands plus other state information related to interpreting
- * commands, such as variable storage.  Primary responsibility for
- * this data structure is in tclBasic.c, but almost every Tcl
- * source file uses something in here.
+ * One of the following structures exists for each command in
+ * an interpreter.  The Tcl_Command opaque type actually refers
+ * to these structures.
  *----------------------------------------------------------------
  */
 
 typedef struct Command {
+    Tcl_HashEntry *hPtr;	/* Pointer to the hash table entry in
+				 * interp->commandTable that refers to
+				 * this command.  Used to get a command's
+				 * name from its Tcl_Command handle.  NULL
+				 * means that the hash table entry has
+				 * been removed already (this can happen
+				 * if deleteProc causes the command to be
+				 * deleted or recreated). */
     Tcl_CmdProc *proc;		/* Procedure to process command. */
     ClientData clientData;	/* Arbitrary value to pass to proc. */
     Tcl_CmdDeleteProc *deleteProc;
@@ -435,9 +427,21 @@ typedef struct Command {
 				 * command. */
     ClientData deleteData;	/* Arbitrary value to pass to deleteProc
 				 * (usually the same as clientData). */
+    int deleted;		/* Means that the command is in the process
+				 * of being deleted (its deleteProc is
+				 * currently executing).  Any other attempts
+				 * to delete the command should be ignored. */
 } Command;
 
-#define CMD_SIZE(nameLength) ((unsigned) sizeof(Command) + nameLength - 3)
+/*
+ *----------------------------------------------------------------
+ * This structure defines an interpreter, which is a collection of
+ * commands plus other state information related to interpreting
+ * commands, such as variable storage.  Primary responsibility for
+ * this data structure is in tclBasic.c, but almost every Tcl
+ * source file uses something in here.
+ *----------------------------------------------------------------
+ */
 
 typedef struct Interp {
 
@@ -538,7 +542,7 @@ typedef struct Interp {
 				 * stored at partialResult. */
 
     /*
-     * A cache of compiled regular expressions.  See TclCompileRegexp
+     * A cache of compiled regular expressions.  See Tcl_RegExpCompile
      * in tclUtil.c for details.
      */
 
@@ -575,8 +579,8 @@ typedef struct Interp {
 				 * determined. */
     int evalFlags;		/* Flags to control next call to Tcl_Eval.
 				 * Normally zero, but may be set before
-				 * calling Tcl_Eval to an OR'ed combination
-				 * of TCL_BRACKET_TERM and TCL_RECORD_BOUNDS. */
+				 * calling Tcl_Eval.  See below for valid
+				 * values. */
     char *termPtr;		/* Character just after the last one in
 				 * a command.  Set by Tcl_Eval before
 				 * returning. */
@@ -594,6 +598,24 @@ typedef struct Interp {
 				/* Static space for storing small results. */
 } Interp;
 
+/*
+ * EvalFlag bits for Interp structures:
+ *
+ * TCL_BRACKET_TERM	1 means that the current script is terminated by
+ *			a close bracket rather than the end of the string.
+ * TCL_RECORD_BOUNDS	Tells Tcl_Eval to record information in the
+ *			evalFirst and evalLast fields for each command
+ *			executed directly from the string (top-level
+ *			commands and those from command substitution).
+ * TCL_ALLOW_EXCEPTIONS	1 means it's OK for the script to terminate with
+ *			a code other than TCL_OK or TCL_ERROR;  0 means
+ *			codes other than these should be turned into errors.
+ */
+
+#define TCL_BRACKET_TERM	1
+#define TCL_RECORD_BOUNDS	2
+#define TCL_ALLOW_EXCEPTIONS	4
+
 /*
  * Flag bits for Interp structures:
  *
@@ -695,18 +717,6 @@ extern char tclTypeTable[];
 #define TCL_BACKSLASH		7
 #define TCL_DOLLAR		8
 
-/*
- * Additional flags passed to Tcl_Eval.  See tcl.h for other flags to
- * Tcl_Eval;  these ones are only used internally by Tcl.
- *
- * TCL_RECORD_BOUNDS	Tells Tcl_Eval to record information in the
- *			evalFirst and evalLast fields for each command
- *			executed directly from the string (top-level
- *			commands and those from command substitution).
- */
-
-#define TCL_RECORD_BOUNDS	0x100
-
 /*
  * Maximum number of levels of nesting permitted in Tcl commands (used
  * to catch infinite recursion).
@@ -737,7 +747,6 @@ extern char tclTypeTable[];
 
 extern int		tclNumFiles;
 extern OpenFile **	tclOpenFiles;
-extern char *		tclRegexpError;
 
 /*
  *----------------------------------------------------------------
@@ -747,14 +756,14 @@ extern char *		tclRegexpError;
  */
 
 extern void		panic();
-extern regexp *		TclCompileRegexp _ANSI_ARGS_((Tcl_Interp *interp,
-			    char *string));
 extern void		TclCopyAndCollapse _ANSI_ARGS_((int count, char *src,
 			    char *dst));
 extern void		TclDeleteVars _ANSI_ARGS_((Interp *iPtr,
 			    Tcl_HashTable *tablePtr));
 extern void		TclExpandParseValue _ANSI_ARGS_((ParseValue *pvPtr,
 			    int needed));
+extern void		TclExprFloatError _ANSI_ARGS_((Tcl_Interp *interp,
+			    double value));
 extern int		TclFindElement _ANSI_ARGS_((Tcl_Interp *interp,
 			    char *list, char **elementPtr, char **nextPtr,
 			    int *sizePtr, int *bracePtr));
@@ -765,6 +774,7 @@ extern int		TclGetFrame _ANSI_ARGS_((Tcl_Interp *interp,
 extern int		TclGetListIndex _ANSI_ARGS_((Tcl_Interp *interp,
 			    char *string, int *indexPtr));
 extern Proc *		TclIsProc _ANSI_ARGS_((Command *cmdPtr));
+extern int		TclNeedSpace _ANSI_ARGS_((char *start, char *end));
 extern int		TclParseBraces _ANSI_ARGS_((Tcl_Interp *interp,
 			    char *string, char **termPtr, ParseValue *pvPtr));
 extern int		TclParseNestedCmd _ANSI_ARGS_((Tcl_Interp *interp,
@@ -781,6 +791,7 @@ extern char *		TclPrecTraceProc _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *interp, char *name1, char *name2,
 			    int flags));
 extern void		TclSetupEnv _ANSI_ARGS_((Tcl_Interp *interp));
+extern int		TclUpdateReturnInfo _ANSI_ARGS_((Interp *iPtr));
 extern char *		TclWordEnd _ANSI_ARGS_((char *start, int nested,
 			    int *semiPtr));
 
@@ -864,6 +875,8 @@ extern int	Tcl_SplitCmd _ANSI_ARGS_((ClientData clientData,
 		    Tcl_Interp *interp, int argc, char **argv));
 extern int	Tcl_StringCmd _ANSI_ARGS_((ClientData clientData,
 		    Tcl_Interp *interp, int argc, char **argv));
+extern int	Tcl_SubstCmd _ANSI_ARGS_((ClientData clientData,
+		    Tcl_Interp *interp, int argc, char **argv));
 extern int	Tcl_SwitchCmd _ANSI_ARGS_((ClientData clientData,
 		    Tcl_Interp *interp, int argc, char **argv));
 extern int	Tcl_TraceCmd _ANSI_ARGS_((ClientData clientData,
