@@ -11,7 +11,7 @@
  */
 
 #ifndef lint
-static char sccsid[] = "@(#) tclMain.c 1.21 95/06/08 10:55:55";
+static char sccsid[] = "@(#) tclMain.c 1.22 95/09/27 15:32:01";
 #endif
 
 #include <stdio.h>
@@ -230,7 +230,13 @@ Tcl_Main(argc, argv, appInitProc)
 	if (code != TCL_OK) {
 	    fprintf(stderr, "%s\n", interp->result);
 	} else if (tty && (*interp->result != 0)) {
-	    printf("%s\n", interp->result);
+	    /*
+	     * Important:  use puts and not printf here.  On Solaris 2.3
+	     * and 2.4, and perhaps other systems, printf will dump core
+	     * if interp->result is big.
+	     */
+
+	    puts(interp->result);
 	}
 #ifdef TCL_MEM_DEBUG
 	if (quitFlag) {
