@@ -16,7 +16,7 @@
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  */
 
-static char sccsid[] = "@(#) tclUnixUtil.c 1.56 95/07/22 17:31:36";
+static char sccsid[] = "@(#) tclUnixUtil.c 1.58 95/11/13 14:17:50";
 
 #include "tclInt.h"
 #include "tclPort.h"
@@ -218,7 +218,7 @@ Tcl_ReapDetachedProcs()
     int status, result;
 
     for (detPtr = detList, prevPtr = NULL; detPtr != NULL; ) {
-	result = waitpid(detPtr->pid, &status, WNOHANG);
+	result = (int) waitpid((pid_t) detPtr->pid, &status, WNOHANG);
 	if ((result == 0) || ((result == -1) && (errno != ECHILD))) {
 	    prevPtr = detPtr;
 	    detPtr = detPtr->nextPtr;
@@ -691,6 +691,9 @@ Tcl_CreatePipeline(interp, argc, argv, pidArrayPtr, inPipePtr,
 	    goto error;
 	}
 	execName = Tcl_TildeSubst(interp, argv[firstArg], &buffer);
+	if (execName == NULL) {
+	    goto error;
+	}
 	pid = vfork();
 	if (pid == 0) {
 	    if (((inputId != -1) && (dup2(inputId, 0) == -1))
@@ -1424,7 +1427,7 @@ TclWaitpid(pid, statPtr, options)
 {
     int result;
     while (1) {
-	result = waitpid(pid, statPtr, options);
+	result = (int) waitpid((pid_t) pid, statPtr, options);
 	if ((result != -1) || (errno != EINTR)) {
 	    return result;
 	}
